@@ -4,7 +4,6 @@
 #' @param address URL address of the metadata file
 #' @param rank stations' rank
 #' @param interval temporal interval
-#' @importFrom RCurl getURL
 #' @importFrom utils read.fwf
 #' @importFrom stats na.omit
 #' @keywords internal
@@ -18,8 +17,21 @@
 #'
 
 clean_metadata_meteo <- function(address, rank = "synop", interval = "hourly"){
+  
+  temp = tempfile()
+  
+  test_url(link = address, output = temp)
+  a = readLines(temp, warn = FALSE)
+  
+  # if (!httr::http_error(address)) {
+  #   a = readLines(address, warn = FALSE)
+  # } else {
+  #   a = stop(call. = FALSE, 
+  #        paste0("\nDownload failed. ",
+  #               "Check your internet connection or validate this url in your browser: ",
+  #               url, "\n"))
+  # }
 
-  a <- readLines(address, warn = FALSE)
   a <- iconv(a, from = "cp1250", to = "ASCII//TRANSLIT") # usuwamy polskie znaki, bo to robi spore "kuku"
   a <- gsub(a, pattern = "\\?", replacement = "") # usuwamy znaki zapytania powstale po konwersji
   
@@ -38,7 +50,7 @@ clean_metadata_meteo <- function(address, rank = "synop", interval = "hourly"){
 
   if(rank == "precip" && interval == "hourly") length_char <- 40 # wyjatek dla precipow
   if(rank == "precip" && interval == "daily") length_char <- 40 # wyjatek dla precipow dobowych
-  if(rank == "synop" && interval == "hourly") length_char <- 60 # wyjatek dla synopow terminowych
+  #if(rank == "synop" && interval == "hourly") length_char <- 60 # wyjatek dla synopow terminowych
 
   field <- substr(a$V1, length_char - 3, length_char)
 
@@ -51,6 +63,9 @@ clean_metadata_meteo <- function(address, rank = "synop", interval = "hourly"){
   a$field2 <- suppressWarnings(as.numeric(unlist(lapply(strsplit(field, "/"), function(x) x[2]))))
 
   a$V1 <- trimws(substr(a$V1, 1, nchar(a$V1) - 3))
+  
+  strsplit(x = a$V1, split = "/")
+  
   #a <- a[nchar(a$V1)>2,] # usuwamy puste lub prawie puste wiersze dodatkowo...
   a <- a[!(is.na(a$field1) & is.na(a$field2)), ] # usuwanie info o statusach
   colnames(a)[1] <- "parameters"
